|
How to make EvoTrees.jl more performant?
|
|
25
|
2038
|
August 25, 2021
|
|
PaddedViews very slow
|
|
7
|
785
|
August 25, 2021
|
|
A demo is 1.5x faster in Flux than tensorflow, both use cpu; while 3.0x slower during using CUDA
|
|
5
|
1685
|
August 25, 2021
|
|
Transducers and reduct-like reduction
|
|
3
|
573
|
August 24, 2021
|
|
Fast large binary heap for SNIC super-pixel
|
|
2
|
506
|
August 24, 2021
|
|
Using closures for performance gain when handling datasets and making repeated function calls
|
|
3
|
695
|
August 24, 2021
|
|
How to use threads in a reduction with LoopVectorization?
|
|
3
|
737
|
August 23, 2021
|
|
Why is minimum so much faster than argmin?
|
|
11
|
2254
|
August 23, 2021
|
|
How to dispatch this serializer function?
|
|
37
|
1990
|
August 23, 2021
|
|
Minimum Mode Problem: minimum number - maximum repetition
|
|
7
|
670
|
August 22, 2021
|
|
Generated functions for performance auto-tuning
|
|
7
|
793
|
August 23, 2021
|
|
Any suggestions for speeding this simple scalar function up?
|
|
36
|
2826
|
August 22, 2021
|
|
Unexpected Allocation with Iterator Extension
|
|
2
|
514
|
August 22, 2021
|
|
Julia implementation of seqperiod (from MATLAB)
|
|
12
|
1030
|
August 21, 2021
|
|
Efficient use of @turbo for linear algebra operations (LoopVectorization.jl)
|
|
6
|
4286
|
August 21, 2021
|
|
Avoid memory allocation in passing arrays
|
|
14
|
2732
|
August 21, 2021
|
|
Can this contraction run faster without memory allocation?
|
|
0
|
368
|
August 21, 2021
|
|
How do findall ,findmax ,findmin, argmax, argmin work on SparseArrays/SparseMatrixCSC
|
|
3
|
592
|
August 20, 2021
|
|
Memory Allocation on Array Element Operations
|
|
2
|
423
|
August 19, 2021
|
|
Speed comparison matrix multiplication in Julia
|
|
45
|
4020
|
August 19, 2021
|
|
LMI, Control system, Robust Control Adaptive Controller
|
|
13
|
1390
|
August 19, 2021
|
|
Allocation-free type hiding?
|
|
14
|
959
|
August 19, 2021
|
|
Accessing profiling data programmatically
|
|
0
|
344
|
August 13, 2021
|
|
Speeding up sort along an array dimension
|
|
11
|
813
|
August 18, 2021
|
|
Running Julia with native Multithreading vs in Seperate Processes
|
|
1
|
431
|
August 18, 2021
|
|
Julia Beginner (from Python): Numba outperforms Julia in rewrite. Any tips to improve performance?
|
|
56
|
7264
|
August 18, 2021
|
|
22 seconds to 3 and now more: Let's fix all of the DifferentialEquations.jl + universe compile times!
|
|
6
|
5197
|
August 17, 2021
|
|
Improving function performance - Broadcasting vs Loops
|
|
14
|
2349
|
August 17, 2021
|
|
BenchmarkGallery?
|
|
1
|
332
|
August 17, 2021
|
|
Object Detection in Julia
|
|
6
|
2382
|
August 17, 2021
|